# Argonne Discovery Cloud SDK & CLI

## Docs: 
https://stage.discoverycloud.anl.gov/docs/sdk/

## Installation

* When positioned in this repo's root directory:
```
pip install adc-sdk
```

## CLI Commands
```
adc create-datafile
adc create-investigation
adc create-job
adc create-sample
adc create-study
adc create-token
adc current-user
adc datafile
adc delete-token
adc investigation
adc job
adc remove-permissions
adc sample
adc set-permissions
adc studies
adc study
adc subscribe-to-investigation
adc subscribe-to-job
adc subscribe-to-study
adc tokens
adc update-job
```
You can run `adc <command> --help` for more information.


## License
This project is licensed under the Apache License - see the [LICENSE](LICENSE) file for details
